/**
 * This brings focus on an element in the page. This class requires the overlay class to be included for it to work.
 * @author briand
 * @created Fri 16 Jul 2010 02:09:58 AM EDT 
 * @modified Sun 25 Jul 2010 04:22:06 Eastern Daylight Time 
 * Copyright (c) 2010 Judicael Briand, MIT Style License
 */
var Qexpose = new Class({
	Implements:[Options, Events],
	options:{
		/*
		 * $onshow, $onhide 
		 */
		/**
		 * this is the color of the overlay
		 */
		color:'#000',
		/**
		 * this is the opacity of the overlay
		 */
		opacity:0.5
	},
	curr:null,
	/**
	 * this instantiates the class
	 * @param {Object} element is the set of elements to add the overlay
	 * @param {Object} options is the options
	 */
	initialize: function(element, options){
		this.setOptions(options);
		$E = document.getElement.bind(document);
		//then we initialize
		this.over = new Qoverlay($(document.body), {
			color:this.options.color,
			opacity:this.options.opacity
		});
		
		this.over.addEvent('click', function(){
			this.hide(this.curr);
		}.bind(this))
		this.zindex=this.over.getz();
		
		//first i convert it to an array
		element = $splat(element);
		element.each(function(i){
			this.add(i);
		}.bind(this));
	},
	/**
	 * This produces an overlay over that element.
	 * @param {Element} i is the element in question
	 */
	show: function(i){
		pos='relative'; if(i.retrieve('pos')=='absolute')pos='absolute';
		//then we add the click event
		i.setStyles({
			position:pos,
			zIndex:this.zindex+5
		});
		//then we set the currently overlayed item to this
		this.curr = i;
		this.over.show();
		this.fireEvent('show', [i]);
	},
	/**
	 * this removes the overlay on an element
	 * @param {Element}i is the element to remove the overlay from.
	 */
	hide: function(i){
		i.setStyles({
			zIndex:i.retrieve('zin'),
			position:i.retrieve('pos')
		});
		this.curr.blur();
		this.over.hide();
		this.fireEvent('hide', i);
	},
	/**
	 * this adds an element to the list of overlayed items
	 * @param {Element}e is the new element to add
	 */
	add: function(e){
		//first let's store the position and zindex of the element
		e.store('pos', e.getStyle('position')); e.store('zin', e.getStyle('zindex'));
		
		e.addEvents({
			'click': function(ev){
				if(ev)ev.stop();
				this.show(e)
			}.bind(this),
			
			'focus': function(){
				this.fireEvent('click');
			},
			
			'blur':function(){
				this.hide(e)
			}.bind(this)
		});
	}
});
