/**
 * This creates an animation for a menu bar. This slides a small element which follows the direction of the mouse over the 
 * menu items.
 * @author briand
 * @created Fri 16 Jul 2010 02:09:58 AM EDT 
 * @modified Thu 5 Aug 2010 05:12:06 Eastern Daylight Time 
 * Copyright (c) 2010 Judicael Briand, MIT Style License
 */
var Qmenu = new Class({
	Implements: [Options, Events],
	
	options:{
		/**
		 * the class for the item
		 */
		style:'qmenu',
		/**
		 * this is the class name for the currently selected item in the menu
		 */
		curr:'curr',
		/**
		 * transision during the movement of the menu
		 */
		trans:'linear',
		/**
		 * the duration for the transition
		 */
		duration:400,
		/**
		 * whether to keep the class of the current element during transition
		 */
		keep:false
	},
	
	initialize: function(element, options){
		this.setOptions(options);
		//then we select our element
		this.menu = $(element);
		//we take the current element
		this.curr = $pick(this.menu.getElement(this.options.curr), this.menu.getElement('li'));
		//then we add the event
		this.menu.getElements('li').each(function(e){
			e.addEvents({
				mouseenter: function(){
					this.move(e);
					//if we are not at the curent element, then let's move to that place
					if(!e.hasClass(this.options.curr)){
						//then check if we have to remove it
						if(!this.options.keep)this.curr.removeClass(this.options.curr);
					}
				}.bind(this),
				
				mouseleave: function(){
					this.move(this.curr); if(!this.options.keep)this.curr.addClass(this.options.curr)
				}.bind(this)
			});
			//then the styles
			e.setStyles({
				position:'relative',
				zIndex:6
			})
		}.bind(this));
		
		co=this.curr.getCoordinates();
		//now we create our little element
		this.anim = new Element('li',{
			styles:{
				position:'absolute',
				zIndex:5,
				padding:0,
				width: co.width,
				height: co.height,
				top: co.top,
				left:co.left
			},
			morph:{
				transition:this.options.trans,
				duration:this.options.duration
			},
			'class':this.options.style
		}).inject(this.menu);
	},
	/**
	 * This moves the animator to 
	 * @param {Element} e which is an li in the menu
	 */
	move: function(e){
		co = e.getCoordinates();
		//we make our morph
		this.anim.morph({
			width: co.width-this.anim.getStyle('borderWidth').toInt(),
			height: co.bottom-co.top,
			top: co.top,
			left:co.left-e.getStyle('borderLeftWidth').toInt()
		});
	}
})
