/**
 * This enhances the abilities of the input field. It allows you to send messages to many destinations.
 * @author briand
 * @created Sun 08 Aug 2010 14:57:32 Eastern Daylight Time
 * @modified Fri 13 Aug 2010 11:04:14 Eastern Daylight Time 
 * Copyright (c) 2010 Judicael Briand, MIT Style License
 */
var Qto = new Class({
	Implements:[Options, Events],
	
	options:{
		/*
		 * $onclick, $onclose, $onadd
		 */
	},
	
	initialize:function(input, options){
		this.setOptions(options); this.id=0; this.top=0; this.curr=null;
		//then we set the input field of the class
		this.input=$(input); co=this.input.getCoordinates();
		//then we add the holder element
		this.holder = new Element('ul',{
			'class':'qto-holder',
			styles:{
				'width':co.width,
				'cursor':'text'
			}
		});
		//then we set the current input[text] to no display
		this.input.setStyle('display','none');
		this.setup();
		this.holder.inject(this.input, 'before');
		//then we save the value of the top
		this.top = this.li.getCoordinates().top;
		this.height=this.holder.getStyle('height').toInt();
		this.array = [];
	},
	
	/**
	 * this allows to create a hidden input for every new element added to the textbox
	 * @param {Object} value is the value of the input
	 */
	addHidden:function(val){
		return new Element({
			type:'hidden',
			name:(this.input.get('name')+'[]'),
			id:(this.element.get('id')+'[]'),
			value:val
		});
	},
	/**
	 * This sets up the li and input for the user to be able to type
	 */
	setup:function(){
		//we create our list element
		this.li = new Element('li',{
			'class':'qto-it',
			'id':'qto-in'
		});
		//then the input
		this.field = new Element('input',{
			'type':'text',
			'class':'qto-text',
			'id':'qto-text',
			'styles':{
				'border':'none',
				'background':'transparent',
				'outline':'none'
			}
		});
		//we attach events
		this.attachEvents();
		//then the holder
		this.holder.addEvent('click', function(){
			this.field.focus();
		}.bind(this));
		//then we add the input to the list
		this.li.grab(this.field);
		this.holder.grab(this.li);
	},
	
	attachEvents: function(){
		this.field.addEvents({
				'keyup':function(e){
					//if he presses enter
					if(e.code==13){
						v=this.field.get('value');
						if (v.trim() != '') {
							this.add(v); this.field.set('value', '');
						}
					}
				}.bind(this),
			});
	},
	
	add:function(item){
		//we create the item and add the close button
		i = new Element('li',{
			'class':'qto-item',
			'rel': this.id++,
			'styles':{
				'cursor':'default'
			}
		}).grab(new Element('div', {
			'html':item, 
			'styles': {
				'padding-top':'3px',
				'float':'left'
			}
		}));
		id=this.id;
		//we then create a reference to the class
		cl=new Element('div',{
			'class':'close',
			'events':{
				'click':function(){
					this.getParent().destroy()
				}
			}
		}).inject(i).addEvent('click', function(){
			this.checkT();
		}.bind(this));
		
		//then we adjust
		i.inject(this.li, 'before'); this.checkT();
	},
	
	set: function(i, val){
		this.array[i]=val;
		
	},
	
	close: function(i){
		$(i).getParent().dispose();
		this.checkT();
	},
	/**
	 * this function checks if the top position of the input field changes,
	 * it adjusts the height of the holder accordingly 
	 */
	checkT: function(){
		t = this.li.getCoordinates().top;
		if(t>this.top){
			this.top = this.li.getCoordinates().top; dm=this.holder.getStyles('height', 'paddingBottom');
			h=dm.height.toInt()+dm.paddingBottom.toInt();
			this.holder.tween('height', h+this.height);
		}else if(t<this.top){
			this.top = this.li.getCoordinates().top; dm=this.holder.getStyles('height', 'paddingBottom');
			h=dm.height.toInt()-dm.paddingBottom.toInt();
			this.holder.tween('height', h-this.height);
		}
	},
});
